@@ -80,9 +80,10 @@ private:
     void cleanTempEnvironment();
     bool isSetupDone() const;
     void setupFailed();
+    void writeAkonadiserverrc(const QString &path);
 
 private:
-    KProcess *mAkonadiDaemonProcess;
+    KProcess *mAkonadiDaemonProcess = nullptr;
     bool mShuttingDown;
     bool mAgentsCreated;
     bool mTrackAkonadiProcess;
