@@ -46,11 +46,17 @@ class Connection;
 class FetchHelper
 {
 public:
-    FetchHelper(Connection *connection, const Scope &scope, const Protocol::ItemFetchScope &fetchScope);
-    FetchHelper(Connection *connection, CommandContext *context, const Scope &scope, const Protocol::ItemFetchScope &fetchScope);
+    FetchHelper(Connection *connection, const Scope &scope,
+            const Protocol::ItemFetchScope &itemFetchScope,
+            const Protocol::TagFetchScope &tagFagScope);
+    FetchHelper(Connection *connection, CommandContext *context, const Scope &scope,
+            const Protocol::ItemFetchScope &itemFetchScope,
+            const Protocol::TagFetchScope &tagFetchScope);
 
     bool fetchItems(std::function<void(Protocol::FetchItemsResponse &&)> &&callback = {});
 
+    void disableATimeUpdates();
+
 private:
     enum ItemQueryColumns {
         ItemQueryPimItemIdColumn,
@@ -86,8 +92,10 @@ private:
     CommandContext *mContext = nullptr;
     QHash<Collection::Id, QVector<Protocol::Ancestor>> mAncestorCache;
     Scope mScope;
-    Protocol::ItemFetchScope mFetchScope;
+    Protocol::ItemFetchScope mItemFetchScope;
+    Protocol::TagFetchScope mTagFetchScope;
     int mItemQueryColumnMap[ItemQueryColumnCount];
+    bool mUpdateATimeEnabled = true;
 
     friend class ::FetchHelperTest;
 };
