@@ -33,8 +33,9 @@ namespace Server
  */
 class Logout : public Handler
 {
-    Q_OBJECT
 public:
+    ~Logout() override = default;
+
     bool parseStream() override;
 
 };
